@@ -74,7 +74,7 @@ ACCESSMASK_UNIT_SUPER: int = sum(
     ]
 )
 
-ACCESSMASK_UNIT_FULL: int = sum([flags.ACCESSFLAG_FULL_ACCESS])
+ACCESSMASK_UNIT_FULL: int = flags.ACCESSFLAG_FULL_ACCESS
 
 ACCESSMASK_UNIT_MIGRATION: int = sum(
     [
